@@ -1,10 +1,10 @@
-from typing import Dict, Union, Optional
+from typing import Dict, Optional, Union
 
 
 def example_func(a: Optional[str], b: Union[str, int, None] = None) -> Dict[str, int]:
     """Example function
 
-    Hover over the paramter and return type annotations to see the long versions.
+    Hover over the parameter and return type annotations to see the long versions.
 
     Args:
         a: An example parameter
